/*
 * BlurredImage.hpp
 *
 *  Created on: 13 dec. 2015
 *      Author: user
 */

#ifndef TEXTDEBLURPAN_BLURREDIMAGE_HPP_
#define TEXTDEBLURPAN_BLURREDIMAGE_HPP_

#include <glib.h>
#include <libgimp/gimp.h>
#include "ImageParameter.hpp" // Include header of the base class
#include <opencv2/core/core.hpp>
#include <opencv2/opencv.hpp>

/**
 * class representing the blurred image which is used as input to the deblurring algorithm.
 */
class BlurredImage : public ImageParameter
{
private:
  double pi = 3.14159265358979323846;
  gint optimalSize[4097]; //inclusief 0!
  cv::Mat imageOriginalOneChannel;
  cv::Mat imageOriginal;
  cv::Mat imagePadded;
  gdouble gammaCorrection;
  cv::Size sizeRescaled;
  void initializeOptimalSize(void);
  void wrapBoundaryLiu(cv::Size size) throw (std::domain_error);
  static cv::Mat interp2(const cv::Mat& src, gdouble scale) throw (std::domain_error);

public:
  BlurredImage();
  BlurredImage(cv::Mat& blurredImage, gdouble gammaCorrection) throw (std::domain_error);
  void resizeForFFT(gdouble factor, gint kernelSize, bool oneChannel = true) throw (std::domain_error);
  gint getOptimalSize(gint size); // voor testdoeleinden
  void solveMinLaPlacion(cv::Mat& image);
  void setImageOriginalOneChannel(cv::Mat mat, bool useGammaCorrection=true) throw (std::domain_error);
  void setImageNoPadding();
  void setImagePadding();
  cv::Mat downSmpImg(cv::Mat image, double factor) throw (std::domain_error);
  cv::Size getOriginalOneChannelSize();
  gdouble getGammaCorrection();
  void setGammaCorrection(gdouble gammaCorrection);
  cv::Mat getImageOriginal();
  cv::Mat getImageOriginalOneChannel();
  cv::Size getSizeRescaled();
  void setSizeRescaled(cv::Size size);
  void setImagePadded(cv::Mat mat);
  cv::Mat getImagePadded();
  void setImageOriginal(cv::Mat mat) throw (std::domain_error);

};

#endif /* TEXTDEBLURPAN_BLURREDIMAGE_HPP_ */
