/*
 * ImageParameter.hpp
 *
 * @author  E. van Schaijk
 * @author  T. Poppe
 * @version  1.0
 * @since  July, 2016
 *
 * This code implements the image deblurring algorithm described in the paper:
 * Jinshan Pan, Zhe Hu, ZhixiJinshan Pan, Zhe Hu, Zhixun Su, and Ming-Hsuan Yang,
 * "Deblurring Text Images via L0-Regularized Intensity and Gradient Prior",
 * CVPR 2014.
 *
 */

#ifndef TEXTDEBLURPAN_IMAGEPARAMETER_HPP_
#define TEXTDEBLURPAN_IMAGEPARAMETER_HPP_
#include <opencv2/core/core.hpp>
#include <stdexcept>
#include <glib.h>

/**
 * Class representing a variable used in image processing.
 */
class ImageParameter{

private:

protected:
  cv::Mat image; ///< Mat for holding the image on which the various methods are applied.

public:
  ImageParameter();
  gint getCurrentWidth(void);
  gint getCurrentHeight(void);
  cv::Mat getImage(void);
  void setImage(cv::Mat image);
  cv::Mat getXGrad(void) throw (std::domain_error);
  cv::Mat getYGrad(void) throw (std::domain_error);
  static cv::Mat dst(const cv::Mat src);
  static cv::Mat idst(const cv::Mat src);
  static cv::Mat fft2(const cv::Mat& src);
  static cv::Mat ifft2(const cv::Mat& src);
  static cv::Mat conjFFT(const cv::Mat& src);
  static cv::Mat psf2otf(const cv::Mat& psf, cv::Size size) throw (std::domain_error);
  static cv::Mat otf2psf(const cv::Mat& otf, cv::Size size) throw (std::domain_error);
  static cv::Mat conj(const cv::Mat& src);
  static cv::Mat absModules(const cv::Mat& src);
  static cv::Mat mulComplex(const cv::Mat& srcA, const cv::Mat& srcB);
  static cv::Mat divComplex(const cv::Mat& srcA, const cv::Mat& srcB);
  static cv::Mat signum(cv::Mat& src);
  static cv::Mat cosPerElement(cv::Mat src);
  cv::Mat getMagnitude(void);
  cv::Mat conv2(const cv::Mat& filter) throw (std::domain_error);
  static cv::Mat circularShift(const cv::Mat& img, gint rows, gint cols) throw (std::domain_error);

};

#endif /* TEXTDEBLURPAN_IMAGEPARAMETER_HPP_ */
