/*
 * DeblurPanPlugin.h
 *
 * @author  T. Poppe
 * @author  E. van Schaijk
 * @version  1.0
 * @since  July, 2016
 *
 */

#ifndef TEXTDEBLURPANGUI_DEBLURPANPLUGIN_H_
#define  TEXTDEBLURPANGUI_DEBLURPANPLUGIN_H_
#include <libgimp/gimp.h>
#include <libgimp/gimpui.h>
#include <gdk-pixbuf/gdk-pixbuf.h>

/*
 *  used to store and retrieve the deblur parameters settings
 */
typedef struct
{
  gint kernelSize;
  gdouble lambdaPixel;
  gdouble lambdaGrad;
  gint numberIterations;
  gboolean preview;
  gdouble lambdaTV;
  gdouble lambdaL0;
  gboolean weightRing;
  GtkProgressBar  *progressPreview;
  GtkProgressBar  *progressMain;
  gboolean gammaCorrectionBoolean;
  gint kernelMaxSize; // is adjusted dynamically
} DeblurParam;

/*
 * Used to stored the run mode of the Gimp plugin
 */
typedef enum {
  interactive,
  preview,
  nonInteractive
} RunMode;

/*
 * Used to store information on the blurred image and the deblurring result
 */
typedef struct
{
  gint imageHeight;
  gint imageWidth;
  gint x;
  gint y;
  GimpDrawable *drawable;
  GimpPixelRgn *latentPixelRgn;
  GdkPixbuf *kernelPixbuf;
  GdkPixbuf *blurredPixbuf;
  GdkPixbuf *latentPixbuf;
  GdkPixbuf *intermediaryPixbuf;
  GimpPixelRgn *blurredPixelRgn;
  RunMode runMode;
} DeblurImageData;

/*
 * Constants for parameter range setting in the deblurDialog
 */
static const gint KERNELMINSIZE =5;
static const gint KERNELMAXSIZE =99;
static const gdouble LAMBDAPIXELMAX = 0.01;
static const gdouble LAMBDAPIXELMIN = 0;
static const gdouble LAMBDAGRADMAX = 0.01;
static const gdouble LAMBDAGRADMIN = 0.0001;
static const gdouble LAMBDATVMAX = 0.1;
static const gdouble LAMBDATVMIN = 0.001;
static const gint NUMBERITERMIN = 1;
static const gint NUMBERITERMAX = 25;

/*
 * Creates the preview image
 */
void deblurPreview (DeblurParam *deblur_param, GimpPreview  *preview);


#endif /* TEXTDEBLURPANGUI_DEBLURPANPLUGIN_H_ */
