/*
 * ProgressBarUpdater.cpp
 *
 * @author  T. Poppe
 * @author  E. van Schaijk
 * @version  1.0
 * @since  July, 2016
 *
 *  This class is responsible for updating the progress bar of both the deblurDialog and the main GIMP progress bar.
 *  It is designed following the observer pattern.
 *  The observable class class the update method for updating the progress bar
 */


#include "ProgressBarUpdater.hpp"

#include <glib.h>
#include <iostream>

using namespace std;

/**
 * Constructor for the ProgressBarUpdater
 * Note that in case of the plug-in is called in nonInteractive mode then no plug-in progress bar is active,
 * only the GIMP main progress bar.
 *
 * @param progressbar	A pointer to the progressbar. This is either the progress bar for the preview,
 * 		 the main progress bar of the deblurDialog or empty in case of nonInteractive mode
 */
ProgressBarUpdater::ProgressBarUpdater(GtkProgressBar *progressbar){
	_progressbar = progressbar;
}


/**
 * The method used to update the progress bar according to the observer/observable pattern.
 * The new value for the progress bar is sent together a parameter of the update methode and
 * is used to adjust the progress bar value.
 *
 * @param	fraction	The fraction defined a percentage completed to which the progress bar needs to be set.
 */
void ProgressBarUpdater::update(double fraction){
	if (_progressbar != NULL){
	  gtk_progress_bar_set_fraction(_progressbar, fraction);
	}
	gimp_progress_update(fraction);
	while (gtk_events_pending ()){
	  gtk_main_iteration ();
	}

}

/**
 * Explicit Destructor because of the superclass.
 */
ProgressBarUpdater::~ProgressBarUpdater(){

}
